"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.withPromise = exports.withCallback = void 0;

/**
 * Open the input with a normal callback function
 *
 * @param {Input} input - input object
 * @param {function} valueMapper - function which maps the resulting id and value back to the expected format
 * @param {function} callback - callback function
 */
var withCallback = function withCallback(input, valueMapper, callback) {
  input.open();
  input.onSelect(function (id, value) {
    return callback(valueMapper(id, value));
  });
};
/**
 * Open the input with a promise
 *
 * @param {Input} input - input object
 * @param {function} valueMapper - function which maps the resulting id and value back to the expected format
 */


exports.withCallback = withCallback;

var withPromise = function withPromise(input, valueMapper) {
  return new Promise(function (resolve, reject) {
    input.open();
    input.onSelect(function (id, value) {
      if (id === null) {
        reject();
      } else {
        resolve(valueMapper(id, value));
      }
    });
  });
};

exports.withPromise = withPromise;