"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _readline = _interopRequireDefault(require("readline"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _instanceof(left, right) { if (right != null && typeof Symbol !== "undefined" && right[Symbol.hasInstance]) { return right[Symbol.hasInstance](left); } else { return left instanceof right; } }

function _classCallCheck(instance, Constructor) { if (!_instanceof(instance, Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

/**
 * Handle cli input
 */
var Input =
/*#__PURE__*/
function () {
  /**
   * Input constructor
   *
   * @param {any} stream - stream to catch (optional)
   */
  function Input() {
    var stream = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : process.stdin;

    _classCallCheck(this, Input);

    // set default values
    this.stream = stream;
    this.values = [];
    this.selectedValue = 0;

    this.onSelectListener = function () {};

    this.onKeyPress = this.onKeyPress.bind(this);
  }
  /**
   * Set the available values
   *
   * @param {array} values - all available values
   */


  _createClass(Input, [{
    key: "setValues",
    value: function setValues(values) {
      this.values = values;

      if (this.renderer) {
        this.renderer.setValues(values);
      }
    }
    /**
     * Set the default value
     *
     * @param {number} defaultValue - default value id
     */

  }, {
    key: "setDefaultValue",
    value: function setDefaultValue(defaultValue) {
      this.selectedValue = defaultValue;
    }
    /**
     * Attach a renderer to the input catcher
     *
     * @param {Renderer} renderer - renderer to use for rendering responses
     */

  }, {
    key: "attachRenderer",
    value: function attachRenderer(renderer) {
      this.renderer = renderer;
      this.renderer.setValues(this.values);
    }
    /**
     * Register an on select listener
     *
     * @param {function} listener - listener function which receives two parameters: valueId and value
     */

  }, {
    key: "onSelect",
    value: function onSelect(listener) {
      this.onSelectListener = listener;
    }
    /**
     * Open the stream and listen for input
     */

  }, {
    key: "open",
    value: function open() {
      // register keypress event
      _readline.default.emitKeypressEvents(this.stream); // handle keypress


      this.stream.on('keypress', this.onKeyPress); // initially render the response

      if (this.renderer) {
        this.renderer.render(this.selectedValue);
      } // hide pressed keys and start listening on input


      this.stream.setRawMode(true);
      this.stream.resume();
    }
    /**
     * Close the stream
     *
     * @param {boolean} cancelled - true if no value was selected (optional)
     */

  }, {
    key: "close",
    value: function close() {
      var cancelled = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : false;
      // reset stream properties
      this.stream.setRawMode(false);
      this.stream.pause(); // cleanup the output

      if (this.renderer) {
        this.renderer.cleanup();
      } // call the on select listener


      if (cancelled) {
        this.onSelectListener(null);
      } else {
        this.onSelectListener(this.selectedValue, this.values[this.selectedValue]);
      }
    }
    /**
     * Render the response
     */

  }, {
    key: "render",
    value: function render() {
      if (!this.renderer) {
        return;
      }

      this.renderer.render(this.selectedValue);
    }
    /**
     * Handle key press event
     *
     * @param {string} string - input string
     * @param {object} key - object containing information about the pressed key
     */

  }, {
    key: "onKeyPress",
    value: function onKeyPress(string, key) {
      if (key) {
        if (key.name === 'up' && this.selectedValue > 0) {
          this.selectedValue--;
          this.render();
        } else if (key.name === 'down' && this.selectedValue + 1 < this.values.length) {
          this.selectedValue++;
          this.render();
        } else if (key.name === 'return') {
          this.close();
        } else if (key.name === 'escape' || key.name === 'c' && key.ctrl) {
          this.close(true);
        }
      }
    }
  }]);

  return Input;
}();

exports.default = Input;