"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _readline = _interopRequireDefault(require("readline"));

var _ansiEscapes = require("ansi-escapes");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _instanceof(left, right) { if (right != null && typeof Symbol !== "undefined" && right[Symbol.hasInstance]) { return right[Symbol.hasInstance](left); } else { return left instanceof right; } }

function _classCallCheck(instance, Constructor) { if (!_instanceof(instance, Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

/**
 * Response renderer
 */
var Renderer =
/*#__PURE__*/
function () {
  /**
   * Renderer constructor
   *
   * @param {object} options - renderer options
   * @param {any} stream - stream to write to (optional)
   */
  function Renderer(options) {
    var stream = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : process.stdout;

    _classCallCheck(this, Renderer);

    this.options = options;
    this.stream = stream;
    this.values = [];
    this.initialRender = true;
  }
  /**
   * Set the available values
   *
   * @param {array} values - all available values
   */


  _createClass(Renderer, [{
    key: "setValues",
    value: function setValues(values) {
      this.values = values;
    }
    /**
     * Render the values
     *
     * @param {number} selectedValue - selected value (optional)
     */

  }, {
    key: "render",
    value: function render() {
      var _this = this;

      var selectedValue = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0;

      if (this.initialRender) {
        // hide the cursor initially
        this.initialRender = false;
        this.stream.write(_ansiEscapes.cursorHide);
      } else {
        // remove previous lines and values
        this.stream.write((0, _ansiEscapes.eraseLines)(this.values.length));
      } // output the current values


      this.values.forEach(function (value, index) {
        var symbol = selectedValue === index ? _this.options.selected : _this.options.unselected;
        var indentation = ' '.repeat(_this.options.indentation);

        var renderedValue = _this.options.valueRenderer(value, selectedValue === index);

        var end = index !== _this.values.length - 1 ? '\n' : '';

        _this.stream.write(indentation + symbol + ' ' + renderedValue + end);
      });
    }
    /**
     * Cleanup the console at the end
     */

  }, {
    key: "cleanup",
    value: function cleanup() {
      this.stream.write((0, _ansiEscapes.eraseLines)(this.values.length));
      this.stream.write(_ansiEscapes.cursorShow);
    }
  }]);

  return Renderer;
}();

exports.default = Renderer;