"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.withObjectValues = exports.withArrayValues = void 0;

/**
 * Map incoming and outgoing values if the initial values are an array
 *
 * @param {object} options - cli-select options
 */
var withArrayValues = function withArrayValues(options) {
  return {
    input: options.values,
    output: function output(id, value) {
      return {
        id: id,
        value: value
      };
    }
  };
};
/**
 * Map incoming and outgoing values if the initial values are an object
 *
 * @param {object} options - cli-select options
 */


exports.withArrayValues = withArrayValues;

var withObjectValues = function withObjectValues(options) {
  var originalValues = options.values;
  return {
    input: Object.values(originalValues),
    output: function output(id, value) {
      return {
        id: Object.keys(originalValues)[id],
        value: value
      };
    }
  };
};

exports.withObjectValues = withObjectValues;